spacepy.empiricals.vampolaPA — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- empiricals - module with heliospheric empirical modules »

# spacepy.empiricals.vampolaPA

`spacepy.empiricals.` `vampolaPA`(omniflux, **kwargs)

  Pitch angle model of sin^n form

  Parameters: | omniflux : arraylike or float omnidirectional number flux data order : integer or float (optional) order of sin^n functional form for distribution (default=2) alphas : arraylike (optional) pitch angles at which to evaluate the differential number flux (default is 5 to 90 degrees in 36 steps)
  Returns: | dnflux : array differential number flux corresponding to pitch angles alphas alphas : array pitch angles at which the differential number flux was evaluated

  Notes

  Directional number flux integrated over pitch angle from 0 to 90 degrees is a factor of 4*pi lower than omnidirectional number flux.

  Examples

  Omnidirectional number flux of [3000, 6000]

      >>> from spacepy.empiricals import vampolaPA
      >>> vampolaPA(3000, alpha=[45, 90])
      (array([  75.99088773,  151.98177546]), [45, 90])
      >>> data, pas = vampolaPA([3000, 6000], alpha=[45, 90])
      >>> pas
      [45, 90]
      >>> data
      array([[  75.99088773,  151.98177546],
         [ 151.98177546,  303.96355093]])

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- empiricals - module with heliospheric empirical modules »